@@ -152,7 +152,8 @@ def create_title(plugin=None):
             title=lambda: plugin.get_title() or DEFAULT_STREAM_METADATA["title"],
             author=lambda: plugin.get_author() or DEFAULT_STREAM_METADATA["author"],
             category=lambda: plugin.get_category() or DEFAULT_STREAM_METADATA["category"],
-            game=lambda: plugin.get_category() or DEFAULT_STREAM_METADATA["game"]
+            game=lambda: plugin.get_category() or DEFAULT_STREAM_METADATA["game"],
+            url=plugin.url
         )
     else:
         title = args.url
@@ -629,8 +630,11 @@ def authenticate_twitch_oauth():
     client_id = TWITCH_CLIENT_ID
     redirect_uri = "https://streamlink.github.io/twitch_oauth.html"
     url = ("https://api.twitch.tv/kraken/oauth2/authorize"
-           "?response_type=token&client_id={0}&redirect_uri="
-           "{1}&scope=user_read+user_subscriptions").format(client_id, redirect_uri)
+           "?response_type=token"
+           "&client_id={0}"
+           "&redirect_uri={1}"
+           "&scope=user_read+user_subscriptions"
+           "&force_verify=true").format(client_id, redirect_uri)
 
     console.msg("Attempting to open a browser to let you authenticate "
                 "Streamlink with Twitch")
